@@ -1,7 +1,7 @@
 """
 This module can compress the contents of a filesystem.
 
-Currently only the Zip format is supported.
+Currently zip and tar are supported.
 """
 
 from __future__ import absolute_import
@@ -105,7 +105,7 @@ def write_tar(src_fs,
               encoding="utf-8",
               walker=None):
     """
-    Write the contents of a filesystem to a zip file.
+    Write the contents of a filesystem to a tar file.
 
     :param file: Destination file, may be a file name or an open file
         object.
@@ -171,10 +171,11 @@ def write_tar(src_fs,
             tar_info.mtime = mtime
 
             for tarattr, infoattr in tar_attr:
-                if getattr(info, infoattr) is not None:
-                    setattr(tar_info, tarattr, getattr(info, infoattr))
+                if getattr(info, infoattr, None) is not None:
+                    setattr(tar_info, tarattr, getattr(info, infoattr, None))
 
-            tar_info.mode = getattr(info.permissions, 'mode', 0o420)
+            if info.has_namespace('access'):
+                tar_info.mode = getattr(info.permissions, 'mode', 0o420)
 
             if info.is_dir:
                 tar_info.type = tarfile.DIRTYPE
